ActivityAuditContract class

Constructors

ActivityAuditContract({ActivityAuditContractTypeEnum? type, String? domain, String? roleReference, bool? disabled, String? domainReference, String? dateTime, String? userType, String? userName, String? firmReference, String? firmName, TradePartnerActivityAuditContract? customerAuditActivity, TradePartnerActivityAuditContract? supplierAuditActivity, ProductActivityAuditContract? productAuditActivity, InvoiceActivityAuditContract? customerInvoiceAuditActivity, InvoiceActivityAuditContract? supplierInvoiceAuditActivity, JournalActivityAuditContract? journalAuditActivity, BankActivityAuditContract? bankAuditActivity, QuotationActivityAuditContract? quotationAuditActivity, PurchaseOrderActivityAuditContract? purchaseOrderAuditActivity, String? reference, DateTime? creationDate})
Returns a new ActivityAuditContract instance.

Properties

bankAuditActivity BankActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
creationDate DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
customerAuditActivity TradePartnerActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
customerInvoiceAuditActivity InvoiceActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
dateTime String?
Created date time
getter/setter pair
disabled bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
domain String?
domain
getter/setter pair
domainReference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
firmName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
firmReference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
journalAuditActivity JournalActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
productAuditActivity ProductActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
purchaseOrderAuditActivity PurchaseOrderActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
quotationAuditActivity QuotationActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
reference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
roleReference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supplierAuditActivity TradePartnerActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
supplierInvoiceAuditActivity InvoiceActivityAuditContract?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
type ActivityAuditContractTypeEnum?
getter/setter pair
userName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
userType String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ActivityAuditContract?
Returns a new ActivityAuditContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ActivityAuditContract>
mapFromJson(dynamic json) Map<String, ActivityAuditContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ActivityAuditContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.