ConversationContract class

Constructors

ConversationContract({String? roleReference, bool? seen, String? content, String? correspondent, bool? admin, List<DocumentContract> documents = const [], List<String> deletedDocuments = const [], String? reference, DateTime? creationDate})
Returns a new ConversationContract instance.

Properties

admin bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
content String?
Message or document-reference for the attachment
getter/setter pair
correspondent String?
Correspondent user name
getter/setter pair
creationDate DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
deletedDocuments List<String>
getter/setter pair
documents List<DocumentContract>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
reference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
roleReference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seen bool?
Viewed conversation
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ConversationContract?
Returns a new ConversationContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ConversationContract>
mapFromJson(dynamic json) Map<String, ConversationContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ConversationContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.