toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'CustomerInvoiceContract[customerCode=$customerCode, draft=$draft, dispute=$dispute, customerReference=$customerReference, date=$date, invoiceNo=$invoiceNo, ref=$ref, dueDate=$dueDate, dueDateAssigned=$dueDateAssigned, vat=$vat, net=$net, gross=$gross, sourceVat=$sourceVat, sourceNet=$sourceNet, sourceGross=$sourceGross, paidAmount=$paidAmount, paidVat=$paidVat, balance=$balance, customerName=$customerName, transactionType=$transactionType, productCode=$productCode, expiryDate=$expiryDate, recurring=$recurring, quotationReference=$quotationReference, taxStatus=$taxStatus, type=$type, actionType=$actionType, frequencyType=$frequencyType, transactionSource=$transactionSource, hasRefund=$hasRefund, disabled=$disabled, paidWithClosedAccount=$paidWithClosedAccount, transactOption=$transactOption, onAccountCurrency=$onAccountCurrency, onAccountExchangeRate=$onAccountExchangeRate, closed=$closed, locked=$locked, autoSuggestionMatched=$autoSuggestionMatched, userNoteCount=$userNoteCount, userNote=$userNote, currency=$currency, exchangeRate=$exchangeRate, todayExchangeRate=$todayExchangeRate, transactions=$transactions, payments=$payments, documents=$documents, deletedDocuments=$deletedDocuments, realisedGainOrLoss=$realisedGainOrLoss, unrealisedGainOrLoss=$unrealisedGainOrLoss, customer=$customer, confidenceScore=$confidenceScore, requiresApproval=$requiresApproval, readyForPost=$readyForPost, blockedByVat=$blockedByVat, blockedByMultiCurrency=$blockedByMultiCurrency, processedDocumentStatus=$processedDocumentStatus, pages=$pages, reference=$reference, creationDate=$creationDate, watching=$watching, watchers=$watchers]';