transactOption property
Option to update or Delete the invoice, like OnAccount, Retract or direct Delete
Implementation
CustomerInvoiceContractTransactOptionEnum? transactOption;
Option to update or Delete the invoice, like OnAccount, Retract or direct Delete
CustomerInvoiceContractTransactOptionEnum? transactOption;