Disable2FARequest class

Constructors

Disable2FARequest({required int code, required String password})
Returns a new Disable2FARequest instance.

Properties

code int
2FA code from authenticator app
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
password String
User's password for confirmation
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Disable2FARequest?
Returns a new Disable2FARequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Disable2FARequest>
mapFromJson(dynamic json) Map<String, Disable2FARequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Disable2FARequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.