GroupRoleContract class

Constructors

GroupRoleContract({String? reference, String? jobTitle, DateTime? expiryDate, String? firstName, String? lastName, GroupRoleContractStatusEnum? status, GroupRoleContractRolePermissionEnum? rolePermission, GroupRoleContractRoleEnum? role})
Returns a new GroupRoleContract instance.

Properties

expiryDate DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
firstName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
jobTitle String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
lastName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
reference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
role GroupRoleContractRoleEnum?
The type of a user
getter/setter pair
rolePermission GroupRoleContractRolePermissionEnum?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GroupRoleContractStatusEnum?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GroupRoleContract?
Returns a new GroupRoleContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GroupRoleContract>
mapFromJson(dynamic json) Map<String, GroupRoleContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GroupRoleContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.