OpeningStockContract class

Constructors

OpeningStockContract({DateTime? date, double? stock, double? costPricePerUnit, bool? openingStockContains, bool? closed, bool? locked})
Returns a new OpeningStockContract instance.

Properties

closed bool?
closed transaction
getter/setter pair
costPricePerUnit double?
Opening stock Cost price per unit
getter/setter pair
date DateTime?
Date
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
locked bool?
locked transaction
getter/setter pair
openingStockContains bool?
opening stock status
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stock double?
Opening stock
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) OpeningStockContract?
Returns a new OpeningStockContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<OpeningStockContract>
mapFromJson(dynamic json) Map<String, OpeningStockContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<OpeningStockContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.