SfinScanDataContract class

Constructors

SfinScanDataContract({String? reference, DateTime? creationDate, SfinScanDataContractStatusEnum? status, SfinScanDataContractScanTypeEnum? scanType, SfinScanDataContractCardinalityEnum? cardinality, String? errors, String? tradePartner, DateTime? date, double? amount, num? numberOfDocuments, List<DocumentContract> files = const []})
Returns a new SfinScanDataContract instance.

Properties

amount double?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
cardinality SfinScanDataContractCardinalityEnum?
getter/setter pair
creationDate DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
date DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
errors String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
files List<DocumentContract>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
numberOfDocuments num?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
reference String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanType SfinScanDataContractScanTypeEnum?
getter/setter pair
status SfinScanDataContractStatusEnum?
getter/setter pair
tradePartner String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SfinScanDataContract?
Returns a new SfinScanDataContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SfinScanDataContract>
mapFromJson(dynamic json) Map<String, SfinScanDataContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SfinScanDataContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.