SfinScanSettingsContractDocumentExtractionTypeEnumTypeTransformer class

Transformation class that can encode an instance of SfinScanSettingsContractDocumentExtractionTypeEnum to String, and decode dynamic data back to SfinScanSettingsContractDocumentExtractionTypeEnum.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(dynamic data, {bool allowNull = true}) SfinScanSettingsContractDocumentExtractionTypeEnum?
Decodes a data to a SfinScanSettingsContractDocumentExtractionTypeEnum.
encode(SfinScanSettingsContractDocumentExtractionTypeEnum data) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited