VatCodeContract class

Constructors

VatCodeContract({String? reference, String? code, double? percentage, String? vatNote, bool? editable, bool? enabled})
Returns a new VatCodeContract instance.

Properties

code String?
vat code
getter/setter pair
editable bool?
vat editable
getter/setter pair
enabled bool?
vat enabled
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
percentage double?
vat percentage
getter/setter pair
reference String?
the reference
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vatNote String?
vat description
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) VatCodeContract?
Returns a new VatCodeContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<VatCodeContract>
mapFromJson(dynamic json) Map<String, VatCodeContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<VatCodeContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.