Contact class
Constructors
Properties
- contactName ↔ String?
-
Contact name
getter/setter pair
- email ↔ String?
-
Email
getter/setter pair
- facsimile ↔ String?
-
Fascimile
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telephone ↔ String?
-
Telephone No
getter/setter pair
- website ↔ String?
-
Website
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Contact? -
Returns a new Contact instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< Contact> -
mapFromJson(
dynamic json) → Map< String, Contact> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< Contact> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.