ConversationContract class
Properties
-
admin
↔ bool?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
content
↔ String?
-
Message or document-reference for the attachment
getter/setter pair
-
correspondent
↔ String?
-
Correspondent user name
getter/setter pair
-
creationDate
↔ DateTime?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
deletedDocuments
↔ List<String>
-
getter/setter pair
-
documents
↔ List<DocumentContract>
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
reference
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
roleReference
↔ String?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
seen
↔ bool?
-
Viewed conversation
getter/setter pair