VatReturnContract class
Constructors
-
VatReturnContract({String? reference, String? periodKey, double? formBundleNumber, String? paymentIndicator, String? chargeRef, String? submitDateTime, DateTime? fromDate, DateTime? toDate, VatReturnContractVatMethodEnum? vatMethod, String? vatScheme, double? box1, double? box2, double? box3, double? box4, double? box5, double? box6, double? box7, double? box8, double? box9, double? payment, String? username, List<
VatReturnTransactionContract> box1Transactions = const [], List<VatReturnTransactionContract> box2Transactions = const [], List<VatReturnTransactionContract> box4Transactions = const [], List<VatReturnTransactionContract> box6Transactions = const [], List<VatReturnTransactionContract> box7Transactions = const [], List<VatReturnTransactionContract> box8Transactions = const [], List<VatReturnTransactionContract> box9Transactions = const []}) - Returns a new VatReturnContract instance.
Properties
- box1 ↔ double?
-
box1
getter/setter pair
-
box1Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- box2 ↔ double?
-
box2
getter/setter pair
-
box2Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- box3 ↔ double?
-
box3
getter/setter pair
- box4 ↔ double?
-
box4
getter/setter pair
-
box4Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- box5 ↔ double?
-
box5
getter/setter pair
- box6 ↔ double?
-
box6
getter/setter pair
-
box6Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- box7 ↔ double?
-
box7
getter/setter pair
-
box7Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- box8 ↔ double?
-
box8
getter/setter pair
-
box8Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- box9 ↔ double?
-
box9
getter/setter pair
-
box9Transactions
↔ List<
VatReturnTransactionContract> -
getter/setter pair
- chargeRef ↔ String?
-
chargeRef
getter/setter pair
- formBundleNumber ↔ double?
-
Form bundle number
getter/setter pair
- fromDate ↔ DateTime?
-
fromDate
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- payment ↔ double?
-
payment
getter/setter pair
- paymentIndicator ↔ String?
-
paymentIndicator
getter/setter pair
- periodKey ↔ String?
-
periodKey
getter/setter pair
- reference ↔ String?
-
reference
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submitDateTime ↔ String?
-
submitDateTime
getter/setter pair
- toDate ↔ DateTime?
-
toDate
getter/setter pair
- username ↔ String?
-
username
getter/setter pair
- vatMethod ↔ VatReturnContractVatMethodEnum?
-
getter/setter pair
- vatScheme ↔ String?
-
vatScheme
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → VatReturnContract? -
Returns a new VatReturnContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< VatReturnContract> -
mapFromJson(
dynamic json) → Map< String, VatReturnContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< VatReturnContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.